pub struct DeviceSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DeviceSynchronousProxy
impl DeviceSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DeviceEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_rail_metadata(
&self,
___deadline: MonotonicInstant,
) -> Result<DeviceGetRailMetadataResult, Error>
pub fn get_rail_metadata( &self, ___deadline: MonotonicInstant, ) -> Result<DeviceGetRailMetadataResult, Error>
Returns metadata for the rail.
Sourcepub fn get_power_watts(
&self,
payload: &Options,
___deadline: MonotonicInstant,
) -> Result<DeviceGetPowerWattsResult, Error>
pub fn get_power_watts( &self, payload: &Options, ___deadline: MonotonicInstant, ) -> Result<DeviceGetPowerWattsResult, Error>
Returns the power consumption. Returns ZX_ERR_NOT_SUPPORTED if the requested measurement type is not supported.
Sourcepub fn get_current_amperes(
&self,
payload: &Options,
___deadline: MonotonicInstant,
) -> Result<DeviceGetCurrentAmperesResult, Error>
pub fn get_current_amperes( &self, payload: &Options, ___deadline: MonotonicInstant, ) -> Result<DeviceGetCurrentAmperesResult, Error>
Returns the current. Returns ZX_ERR_NOT_SUPPORTED if the requested measurement type is not supported.
Sourcepub fn get_energy_joules(
&self,
payload: &Options,
___deadline: MonotonicInstant,
) -> Result<DeviceGetEnergyJoulesResult, Error>
pub fn get_energy_joules( &self, payload: &Options, ___deadline: MonotonicInstant, ) -> Result<DeviceGetEnergyJoulesResult, Error>
Returns the energy consumption. Returns ZX_ERR_NOT_SUPPORTED if the requested measurement type is not supported.