pub struct DriverConfigMarker;Trait Implementations
Sourceimpl Clone for DriverConfigMarker
impl Clone for DriverConfigMarker
Sourcefn clone(&self) -> DriverConfigMarker
fn clone(&self) -> DriverConfigMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DriverConfigMarker
Sourceimpl Debug for DriverConfigMarker
impl Debug for DriverConfigMarker
Sourceimpl DiscoverableProtocolMarker for DriverConfigMarker
impl DiscoverableProtocolMarker for DriverConfigMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for DriverConfigMarker
Sourceimpl Hash for DriverConfigMarker
impl Hash for DriverConfigMarker
Sourceimpl Ord for DriverConfigMarker
impl Ord for DriverConfigMarker
Sourcefn cmp(&self, other: &DriverConfigMarker) -> Ordering
fn cmp(&self, other: &DriverConfigMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DriverConfigMarker
impl PartialEq for DriverConfigMarker
Sourceimpl PartialOrd for DriverConfigMarker
impl PartialOrd for DriverConfigMarker
Sourceimpl ProtocolMarker for DriverConfigMarker
impl ProtocolMarker for DriverConfigMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.hardware.google.odpm.DriverConfig"
const DEBUG_NAME: &'static str = "fuchsia.hardware.google.odpm.DriverConfig"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = DriverConfigProxy
type Proxy = DriverConfigProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = DriverConfigRequestStream
type RequestStream = DriverConfigRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = DriverConfigSynchronousProxy
type SynchronousProxy = DriverConfigSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for DriverConfigMarker